@@ -1,7 +1,7 @@
 
 # The R Commander and command logger
 
-# last modified 2013-01-08 by J. Fox
+# last modified 2013-01-24 by J. Fox
 #  applied patch to improve window behaviour supplied by Milan Bouchet-Valat 2011-09-22
 #   slight changes 12 Aug 04 by Ph. Grosjean
 #   changes 21 June 2007 by Erich Neuwirth for Excel support (marked EN)
@@ -9,6 +9,25 @@
 
 Commander <- function(){
     library(Rcmdr, quietly=TRUE)
+    RcmdrEnv.on.path <- getOption("Rcmdr")[["RcmdrEnv.on.path"]]
+    if (is.null(RcmdrEnv.on.path)) RcmdrEnv.on.path <- (getRversion() < "3.0.0")
+    if (RcmdrEnv.on.path){
+        RcmdrEnv <- function() {
+            pos <-  match("RcmdrEnv", search())
+            if (is.na(pos)) { # Must create it
+                RcmdrAttach <- base::attach
+                RcmdrEnv <- list()
+                RcmdrAttach(RcmdrEnv, pos = length(search()) - 1)
+                rm(RcmdrEnv)
+                pos <- match("RcmdrEnv", search())
+            }
+            return(pos.to.env(pos))
+        }
+        
+        assignInMyNamespace("RcmdrEnv", RcmdrEnv)        
+        assignInMyNamespace(".RcmdrEnv", NULL)
+        
+    }
 	RStudioP <- function() nzchar(Sys.getenv("RSTUDIO_USER_IDENTITY"))
 	DESCRIPTION <- readLines(file.path(.find.package("Rcmdr"), "DESCRIPTION")[1])
 	RcmdrVersion <- trim.blanks(sub("^Version:", "",
